@@ -3,6 +3,7 @@ from .claims import JWTDecodeClaims, JWTEncodeClaims
 from .decoder import JWTDecoder
 from .encoder import JWTEncoder
 from .exceptions import JWTDecodeException, JWTEncodeException, JWTException
+from .helpers import JWTTokenPairIssuer, decode_access_token
 from .identities import Identity, PemIdentity, PlainIdentity
 
 __all__ = (
@@ -19,4 +20,6 @@ __all__ = (
     "JWTDecoder",
     "JWTEncodeClaims",
     "JWTDecodeClaims",
+    "JWTTokenPairIssuer",
+    "decode_access_token",
 )
